SystemOrganization addCategory: #'DAO-SatelliteTests'!

TestCase subclass: #CommandParameterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 16:32'!
testDeserializeNegativeSigned16BitInteger
	| serializedValue parameter streamDeLectura |
	
	serializedValue := #[1 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter new: 16.
	
	self assert: (parameter deserialize: streamDeLectura) equals: -1.! !

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 16:35'!
testDeserializePositiveSigned16BitInteger
| serializedValue parameter streamDeLectura |
	
	serializedValue := #[0 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter new: 16.
	
	self assert: (parameter deserialize: streamDeLectura) equals: 1.! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 14:31'!
testSerializeString8
	| parameter |
	
	parameter := StringCommandParameter new: 8.
	parameter value: 'Hello'.
	
	self assert: (parameter serialize) equals: #[5 72 101 108 108 111].! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 14:27'!
testSerializeUnsigned32BitInteger
	| parameter |
	
	parameter := UnsignedIntegerCommandParameter new: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].! !

TestCase subclass: #CommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 16:54'!
thermalSubsystemNameCommand

	^  GetNameCommand newWithReceiver: SatelliteTest thermalSubsystem andId: 0.
	
! !

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:22'!
thermalSubsystemTelemetryCommand

	^  ThermalTelemetryCommand new.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 18:09'!
testDeserializingArrayOfUnsigned8BitIntegerShouldReturnTheDecodedArray

	| encodedResponse decodedResponse readAddressCommand array |
	
	"setup"
	"001 sequence number, 1 first byte, 2 second"
	encodedResponse := #[0 0 1 1 2].

	readAddressCommand := MemoryReadAddressCommand new.
	
	"exercise"	
	decodedResponse := readAddressCommand deserialize: encodedResponse.
	
	"verify"
	self assert: (decodedResponse data size) equals: 1.
	
	array := (decodedResponse data at: 1).
	
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 19:46'!
testDeserializingThermalNameResponseShouldReturnThermal

	| encodedResponse decodedResponse getNameCommand |

	"001 sequence number, lo que le sigue THERMAL codificado"
	encodedResponse := #[0 0 1 84 72 69 82 77 65 76].
	
	getNameCommand := GetNameCommand new.
	
	decodedResponse := getNameCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data size) equals: 1.
	self assert: (decodedResponse data at: 1) equals: 'THERMAL'.! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 19:53'!
testDeserializingThermalSetMatrixKeyResponseShouldReturnVoid

	| encodedResponse thermalSetMatrixKeyCommand decodedResponse |
	
	"001 sequence number, then empty response"
	encodedResponse := #[0 0 1].
	
	thermalSetMatrixKeyCommand :=  ThermalSetMatrixKeyCommand new.
	
	decodedResponse :=  thermalSetMatrixKeyCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse class) equals: VoidCommandResponse.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 20:37'!
testDeserializingThermalShortTelemetryResponseShouldReturnThermalShortTelemetry

	| encodedResponse thermalShortTelemetryCommand decodedResponse |
	
	"001 sequence number, 1 battery temp"
	encodedResponse := #[0 0 1 1].
	thermalShortTelemetryCommand :=  ThermalShortTelemetryCommand new.
	
	decodedResponse :=  thermalShortTelemetryCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: 1.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 15:06'!
testDeserializingThermalTelemetryResponseContainingNegativeNumbersShouldDeserializeOK

	| encodedResponse decodedResponse thermalTelemetryCommand |
	
	"001 sequence number, 1 1 battery temp, 1 2 radio temp"
	encodedResponse := #[0 0 1 1 1 1 2].

	thermalTelemetryCommand := ThermalTelemetryCommand new.
		
	decodedResponse := thermalTelemetryCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: -1.
	self assert: (decodedResponse data at: 2) equals: -2.
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 15:03'!
testDeserializingThermalTelemetryResponseShouldReturnThermalTelemetry

	| encodedResponse decodedResponse thermalTelemetryCommand |
	
	"001 sequence number, 0 1 battery temp, 0 2 radio temp"
	encodedResponse := #[0 0 1 0 1 0 2].

	thermalTelemetryCommand := ThermalTelemetryCommand new.
		
	decodedResponse := thermalTelemetryCommand deserialize: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: 1.
	self assert: (decodedResponse data at: 2) equals: 2.
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 18:19'!
testDeserializingUsigned32BitIntegerAndArrayOfUnsigned8BitIntegerShouldDeserializeOK

	| encodedResponse decodedResponse readLongAddressCommand array firstElement |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	readLongAddressCommand := MemoryReadLongAddressCommand new.
	
	"exercise"	
	decodedResponse := readLongAddressCommand deserialize: encodedResponse.
	
	"verify"
	self assert: (decodedResponse data size) equals: 2.
	
	firstElement := decodedResponse data at: 1.
	self assert: firstElement equals: 1.
	
	array := (decodedResponse data at: 2).
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandTest methodsFor: 'execution' stamp: 'EzequielDavidovichCaballero 9/29/2013 17:04'!
testSendingNameCommandToThermalSubsystem
	| thermalSubsystem command response |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := GetNameCommand new.
	
	"exercise"
	response := command executeFrom: thermalSubsystem.
	
	"verify"
	self assert: (response message) equals: 'THERMAL'! !

!CommandTest methodsFor: 'execution' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 18:24'!
testSendingSetMatrixKeyCommandToThermalSubsystem
	| thermalSubsystem command response voidResponse |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := ThermalSetMatrixKeyCommand new.
	voidResponse := VoidCommandResponse new.	
	"exercise"
	command addParameterValue: 10.
	response := command executeFrom: thermalSubsystem.
	"verify"
	self assert: response equals: voidResponse.
	self assert: (thermalSubsystem getValueOfAttribute: 'matrix_key') equals: 10! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 15:55'!
testSerializingCommandWithFiveU32ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryReadChunkedAddressCommand new.

	command addParameterValue: 1.
	command addParameterValue: 2.
	command addParameterValue: 3.
	command addParameterValue: 4.
	command addParameterValue: 5.
	
	self assert: command serialize equals: #[45 0 0 0 1 0 0 0 2 0 0 0 3 0 0 0 4 0 0 0 5]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:01'!
testSerializingCommandWithMaxValueSetToOneU24ParameterShouldSerializeOK
	
	| command |
	
	command := PowerStbSetSwitchesStateCommand new.

	command addParameterValue: 16777215.
	
	self assert: command serialize equals: #[36 255 255 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:18'!
testSerializingCommandWithMaxValueSetToOneU8ParameterShouldSerializeOK
	
	| command |
	
	command := PlatformSetModeCommand new.

	command addParameterValue: 255.
	
	self assert: command serialize equals: #[32 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:20'!
testSerializingCommandWithMaxValuesSetToTwoU32ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryReadLongAddressCommand new.

	command addParameterValue: 4294967295.
	command addParameterValue: 4294967295.
	
	self assert: command serialize equals: #[44 255 255 255 255 255 255 255 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:20'!
testSerializingCommandWithOneU24ParameterShouldSerializeOK
	
	| command |
	
	command := PowerStbSetSwitchesStateCommand new.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[36 0 0 1]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 18:25'!
testSerializingCommandWithOneU32AndOneString8ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryWriteAddressCommand new.

	command addParameterValue: 1.
	command addParameterValue: 'Hello'.
	
	self assert: command serialize = #[33 0 0 0 1 5 72 101 108 108 111]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:21'!
testSerializingCommandWithOneU32ParameterShouldSerializeOK
	
	| command |
	
	command := ThermalSetMatrixKeyCommand new.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[32 0 0 0 1]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 9/29/2013 16:21'!
testSerializingCommandWithTwoU32ParametersShouldSerializeOK
	
	| command |
	
	command := MemoryReadLongAddressCommand new.

	command addParameterValue: 1.
	command addParameterValue: 2.
	
	self assert: command serialize equals: #[44 0 0 0 1 0 0 0 2]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:01'!
testSerializingCommandWithoutParametersShouldSerializeCommandIdOnly
	
	| command |
	
	command := CommandTest thermalSubsystemTelemetryCommand.
	
	self assert: command serialize equals: #[1]! !

TestCase subclass: #ControllerLogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenAskingForASequenceNumberNotLoggedTheResultShouldBeFalse
	| log |
	
	log := ControllerLog new.
	
	self deny: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenLoggingARequestTheSequenceNumberIsLogged
	| log |
	
	log := ControllerLog new.
	
	log addRequest: 'telemetry' withSequenceNumber: 1.
	
	self assert: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:14'!
testWhenLoggingARequestUsingAnExistingSequenceNumberShouldArchiveTheOriginalRequest
	"log using a sequence number and then log again using the same sequence number, to make the log archive the first entry"
	| log newLogEntry logEntryForArchiving archivedLogEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'messageMovedToTheArchive' withSequenceNumber: 1.
	self assert: (log containsEntryWithSequenceNumber: 1).
	logEntryForArchiving := log entryWithSequenceNumber: 1.
	
	"exercise"
	"this should archive the first entry"
	log addRequest: 'expectedMessage' withSequenceNumber: 1.
	
	"verify"
	newLogEntry := log entryWithSequenceNumber: 1.
	self assert: (newLogEntry request) equals: 'expectedMessage'.
	archivedLogEntry := log archive at: 1.
	self assert: archivedLogEntry equals: logEntryForArchiving.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:14'!
testWhenLoggingAResponseUsingAnExistingSequenceNumberTheLogEntryShouldContainTheRequestAndTheResponse
	| log logEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'requestMessage' withSequenceNumber: 1.
		
	"exercise"
	log addResponse: 'responseMessage' withSequenceNumber: 1.
	
	"verify"
	logEntry := log entryWithSequenceNumber: 1.
	self assert: (logEntry request) equals: 'requestMessage'.
	self assert: (logEntry response) equals: 'responseMessage'.
! !

TestCase subclass: #SatelliteControllerTest
	instanceVariableNames: 'clientSocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EzequielDavidovichCaballero 9/29/2013 17:07'!
testEncodingNameCommandRequestShouldReturnCorrectString

	| satelliteController nameCommand resultingByteArray |
	
	satelliteController := SatelliteController new.

	nameCommand :=  GetNameCommand new.
	
	resultingByteArray := satelliteController encode: nameCommand withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[78 129 151 0 0 1 1 0]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EzequielDavidovichCaballero 9/29/2013 17:07'!
testEncodingSetMatrixKeyRequestShouldReturnCorrectString

	| satelliteController command resultingByteArray |
	
	satelliteController := SatelliteController new.

	command :=  ThermalSetMatrixKeyCommand new.
	command addParameterValue: 1.
	
	resultingByteArray := satelliteController encode: command withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[225 246 60 0 0 1 3 32 0 0 0 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EzequielDavidovichCaballero 9/29/2013 17:07'!
testEncodingTelemetryRequestShouldReturnCorrectString

	| satelliteController thermalTelCommand resultingByteArray |

	satelliteController := SatelliteController new.
	
	thermalTelCommand := ThermalTelemetryCommand new.

	resultingByteArray := satelliteController encode: thermalTelCommand withSequenceNumber: (SequenceNumber new).

	self assert: resultingByteArray equals: #[90 204 175 0 0 1 1 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 16:09'!
testReceiveBeacon
	| satelliteController stream packageSize package beacon |

	"SatelliteController open socket"	
	satelliteController := SatelliteController new.
	
	stream := satelliteController radioStream.
	
	stream receiveData.
		
	packageSize :=  stream next.
	packageSize := (packageSize bitShift: 8) + stream next.
	packageSize := (packageSize bitShift: 8) + stream next.
	packageSize := (packageSize bitShift: 8) + stream next.
	package := stream next: packageSize.

	stream close.

	beacon := satelliteController decode: package.
	
	self assert: beacon data equals: 'ASDF'.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 16:13'!
testSendGetNameCommand
	| satelliteController commandCall radioStream command |
	
	satelliteController := SatelliteController new.
	
	command := ThermalTelemetryCommand newWithReceiver: (SatelliteTest thermalSubsystem) andId: 1.

	commandCall := self encode: command withSequenceNumber: SequenceNumber new.

	radioStream := satelliteController radioStream.

	"radioStream nextPutAll: #[44 110 127 0 0 1 0 0]; flush."
	radioStream nextPutAll: commandCall; flush.
	
	radioStream receiveData.
	
	satelliteController shutdown.
	
	self assert: (radioStream nextAvailable ) equals: 'ASDF'
! !

TestCase subclass: #SatelliteSubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:19'!
test01WhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := Memory new.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:45'!
test02WhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.

	"verify"	
	self assert: (subsystem understands: 'name').
	self assert: (subsystem understands: 'telemetry').
	self assert: (subsystem understands: 'short_telemetry').
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 21:45'!
test03WhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem  |

	"setup"
	subsystem := SatelliteTest memorySubsystem.

	"verify"	
	self deny: (subsystem understands: 'notACommand').
! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 20:03'!
test04ThermalShortTelemetryShouldReturnOK

	| subsystem expectedShortTelemetry shortTelemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	expectedShortTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	shortTelemetry:=	subsystem shortTelemetry. 

	"verify"	
	self assert: shortTelemetry = expectedShortTelemetry.

! !

!SatelliteSubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 9/28/2013 20:07'!
test05ThermalTelemetryShouldReturnOK

	| subsystem expectedTelemetry telemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	data add: (Association key: 'radio_temp' value: 20).
	expectedTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	telemetry:= subsystem telemetry. 

	"verify"	
	self assert: telemetry = expectedTelemetry.

! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 11:42'!
cdhSubsystem
	| cdhSubsystem |

	cdhSubsystem := CDH new.
	cdhSubsystem setAttribute: 'lastSeenSequenceNumber' withValue: 10.
	cdhSubsystem setAttribute: 'nextBeaconEnableTicks' withValue: 20.
	cdhSubsystem setAttribute: 'antennaDeployStatus' withValue: 30.
	cdhSubsystem setAttribute: 'ticksLow' withValue: 40.
	
	^ cdhSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/29/2013 15:54'!
memorySubsystem
	| memorySub |

	memorySub := Memory new.
	memorySub setAttribute: 'free' withValue: 100.
	
	^ memorySub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/29/2013 15:54'!
platformSubsystem
	| platformSub |

	platformSub := Platform new.
	platformSub setAttribute: 'tick_count' withValue: 1000000.
	platformSub setAttribute: 'current_mode' withValue: 1.
	
	^ platformSub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 12:04'!
powerSubsystem
	| platformSubsystem |

	platformSubsystem := Power new.

	platformSubsystem setAttribute: 'low_voltage_counter' withValue: 1.
	platformSubsystem setAttribute: 'battery_v' withValue: 2.
	platformSubsystem setAttribute: 'array_X_v' withValue: 3.
	platformSubsystem setAttribute: 'array_Xp_mA' withValue: 4.
	platformSubsystem setAttribute: 'array_Xm_mA' withValue: 5.
	platformSubsystem setAttribute: 'array_Y_v' withValue: 6.
	platformSubsystem setAttribute: 'array_Yp_mA' withValue: 7.
	platformSubsystem setAttribute: 'array_Y_mA' withValue: 8.
	platformSubsystem setAttribute: 'array_Z_v' withValue: 9.
	platformSubsystem setAttribute: 'array_Zp_mA' withValue: 10.
	platformSubsystem setAttribute: 'array_Zm_mA' withValue: 11.
	platformSubsystem setAttribute: '_3v3_mA' withValue: 12.
	platformSubsystem setAttribute: '_5v_mA' withValue: 13.
	
	^ platformSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 11:37'!
satelliteWithAllSubsystems
	| subsystems |

	subsystems := OrderedCollection new.
	
	subsystems add: self platformSubsystem.
	subsystems add: self memorySubsystem.
	subsystems add: self thermalSubsystem.
	subsystems add: self powerSubsystem.
	subsystems add: self cdhSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 9/29/2013 15:55'!
thermalSubsystem
	| thermalSub |

	thermalSub := Thermal new.
	thermalSub setAttribute: 'battery_temp' withValue: 10.
	thermalSub setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSub! !

!SatelliteTest methodsFor: 'receiving' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 17:28'!
testDecodeThermalSubsystemNameCommand

	| satellite bytes getNameCommand decodedCommand satelliteController thermalSubsystem |

	"setup"
	satelliteController := SatelliteController new.
	satellite := SatelliteTest satelliteWithAllSubsystems.
	thermalSubsystem := SatelliteTest thermalSubsystem.
	getNameCommand := GetNameCommand newWithReceiver: thermalSubsystem andId: 0.
	bytes := satelliteController encode: getNameCommand withSequenceNumber: SequenceNumber new.

	"exercise"	
	decodedCommand := satellite receive: bytes.

	"verify"	
	self assert: decodedCommand equals: getNameCommand.
	self assert: decodedCommand receiver id equals: thermalSubsystem id.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 17:34'!
testGivenASatelliteWhenEmittingABeaconItShouldReturnCollectedTelemetry

	| satellite beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.

	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.

	expectedBeaconData := subsystemsOrderedById collect: [ :subsystem | subsystem telemetry ].
	
	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon data size equals: satellite subsystems size.
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 17:35'!
testGivenASatelliteWhenEmittingAShortBeaconItShouldReturnCollectedShortTelemetry

	| satellite beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.
	
	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.
	
	expectedBeaconData := subsystemsOrderedById collect: [ :subsystem | subsystem shortTelemetry ].
	
	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon data size equals: satellite subsystems size.
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 17:35'!
testGivenASatelliteWithThermalSubsystemOnlyWhenEmittingABeaconTheBeaconShouldContainOnlyThermalTelemetry

	| satellite subsystems thermalSubsystem beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	thermalSubsystem := Thermal new.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	
	satellite := Satellite newWithSubsystems: subsystems.

	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.

	expectedBeaconData := subsystemsOrderedById collect: [ :subsystem | subsystem telemetry ].

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon data size equals: satellite subsystems size.
	self assert: beacon data equals: expectedBeaconData.
! !

TestCase subclass: #SequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := SequenceNumber new.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := SequenceNumber startingFrom: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := SequenceNumber new.
	
	self assert: sequenceNumber number equals: 1! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNextOfLastNumberIs1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
	sequenceNumber := SequenceNumber startingFrom: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !
